@@ -20,17 +20,7 @@
 ### <======================================================================>
 ldhmm.oxford_man_index_list <- function()
 {
-    get_index <- function(s) {
-        has_rv <- length(grep("[.]rv$", s))
-        if (has_rv > 0) {
-            sp <- unlist(strsplit(s, split="[.]"))
-            return(sp[1])
-        }
-        else return(NA)
-    }
-
     rv <- ldhmm.oxford_man_realized_data()
-    c <- colnames(rv)
-    as.character(na.exclude(unique(sapply(c, get_index))))
+    sort(unique(rv$Symbol))
 }
 ### <---------------------------------------------------------------------->
